Learn R Programming

mexhaz (version 2.6)

fixef.mexhaz: Method for extracting fixed effects from a mexhaz object

Description

Display a vector containing the fixed effects of a mexhaz model.

Usage

# S3 method for mexhaz
fixef(x, ...)

Value

A vector containing the fixed effect estimates.

Arguments

x

an object of class mexhaz.

...

not used.

See Also

mexhaz

Examples

Run this code

data(simdatn1)

## Fit of a mixed-effect excess hazard model, with the baseline hazard
## described by a Weibull distribution (without covariables)

Mod_weib_mix <- mexhaz(formula=Surv(time=timesurv,
event=vstat)~1, data=simdatn1, base="weibull",
expected="popmrate", verbose=0, random="clust")

fixef(Mod_weib_mix)

Run the code above in your browser using DataLab