Learn R Programming

mexhaz (version 2.6)

print.summary.mexhaz: Printing method for a summary.mexhaz object

Description

Display the model call, the values of the estimated model parameters, as well as the corresponding hazard ratios (only for proportional effects).

Usage

# S3 method for summary.mexhaz
print(x, ...)

Arguments

x

an object of class summary.mexhaz.

...

represents additional parameters directly passed to print.

See Also

mexhaz, print.mexhaz, summary.mexhaz

Examples

Run this code

data(simdatn1)

## Fit of a mixed-effect excess hazard model, with the baseline hazard
## described by a Weibull distribution (without covariables)

Mod_weib <- mexhaz(formula=Surv(time=timesurv,
event=vstat)~1, data=simdatn1, base="weibull", verbose=0)

summary(Mod_weib)

Run the code above in your browser using DataLab