Learn R Programming

mexhaz (version 2.6)

ranef.mexhaz: Method for extracting random effects from a mexhaz object

Description

Display a data frame containing the cluster-specific random effects with their standard errors.

Usage

# S3 method for mexhaz
ranef(x, ...)

Value

A data frame with three columns containing the cluster names, the random effect estimates, and their standard errors.

Arguments

x

an object of class mexhaz.

...

not used.

See Also

mexhaz

Examples

Run this code

data(simdatn1)

## Fit of a mixed-effect excess hazard model, with the baseline hazard
## described by a Weibull distribution (without covariables)

Mod_weib_mix <- mexhaz(formula=Surv(time=timesurv,
event=vstat)~1, data=simdatn1, base="weibull",
expected="popmrate", verbose=0, random="clust")

ranef(Mod_weib_mix)

Run the code above in your browser using DataLab