Learn R Programming

mexhaz (version 2.6)

vcov.mexhaz: Method for extracting the covariance matrix of the fixed effects

Description

Display a the covariance matrix of the fixed effects of a mexhaz model.

Usage

# S3 method for mexhaz
vcov(object, ...)

Value

The estimated covariance matrix of the fixed effects.

Arguments

object

an object of class mexhaz.

...

not used.

See Also

mexhaz

Examples

Run this code

data(simdatn1)

## Fit of a mixed-effect excess hazard model, with the baseline hazard
## described by a Weibull distribution (without covariables)

Mod_weib_mix <- mexhaz(formula=Surv(time=timesurv,
event=vstat)~1, data=simdatn1, base="weibull",
expected="popmrate", verbose=0, random="clust")

vcov(Mod_weib_mix)

Run the code above in your browser using DataLab